@@ -37,10 +37,15 @@ class OkexClientAccountBalance(Base, BaseTable):
 
     @staticmethod
     def update():
-        
-        data = account_api.get_account().data[0]['details']
-        create_all()
+        res = account_api.get_account().data
 
-        for detail in data:
-            session.merge(OkexClientAccountBalance(**detail))
-        session.commit()
+        try:
+            data = res[0]['details']
+            create_all()
+            for detail in data:
+                session.merge(OkexClientAccountBalance(**detail))
+                session.commit()
+            return {"success": len(data)}
+        except Exception as e:
+            session.rollback()
+            return {"error": str(e), "res": res}
