@@ -1,5 +1,7 @@
 from .account import AccountAccount
+from .base import BaseAPI
 from .market import MarketTickers
 
 market_tickers = MarketTickers()
 account_account = AccountAccount()
+base_api = BaseAPI()
